# PbiSampleInspectionTargetSummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**pbi_sample_inspection_target_reference_number** | **str** |  | 
**organisation_name** | **str** |  | 
**org_ref** | **str** |  | 
**inspection_units** | **float** |  | 
**inspection_rate** | **float** |  | 
**target_a** | **float** |  | 
**target_b** | **float** |  | 
**target_c** | **float** |  | 
**completed_a** | **float** |  | 
**completed_b** | **float** |  | 
**completed_c** | **float** |  | 
**generated_b** | **float** |  | 
**generated_c** | **float** |  | 
**start_date** | **datetime** |  | [optional] 
**end_date** | **datetime** |  | [optional] 
**is_inspection_rate_auto_updated** | **bool** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

